@@ -1,7 +1,7 @@
 //
 // dell.h
 //
-// Copyright 2012-2015 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class DellRemote1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   DellRemote1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class DellProjector1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   DellProjector1(
     unsigned int index);
