@@ -111,7 +111,7 @@ public:
     QObject *guiObject);
 
   virtual void populateInputList(
-    QComboBox *cb);
+    QComboBox *cb) const;
 };
 
 class NECProjector3: public PIRKeysetMetaData
