@@ -1,7 +1,7 @@
 //
 // russellhobbs.h
 //
-// Copyright 2014 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2014 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class RussellHobbsFan1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   RussellHobbsFan1(
     unsigned int index);
